﻿using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using static InnoLabProjektDektopApp.DistractionsList;
using System.Text.Json;
using System.Text.RegularExpressions;
using System.IO;
using System.Collections.Generic;

namespace InnoLabProjektDektopApp
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class Distractions : Window
    {

        private string jsonFilePath = System.IO.Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "Assets", "distractingWebsites.json");
        private Dictionary<string, List<WebsiteEntry>> ?data;
        public Distractions()
        {
            InitializeComponent();
            GlobalSettings.setDefaults(this);
            LoadJsonData();
        }



        private void SearchBox_TextChanged(object sender, TextChangedEventArgs e)
        {
            // Placeholder ein- oder ausblenden
            if (!string.IsNullOrEmpty(SearchBox.Text))
            {
                SearchPlaceholder.Visibility = Visibility.Collapsed; // Ausblenden
            }
            else
            {
                SearchPlaceholder.Visibility = Visibility.Visible; // Einblenden
            }
        }

        private void CheckBox_Changed(object sender, RoutedEventArgs e)
        {
            if (sender is CheckBox checkBox && checkBox.Tag is (string category, WebsiteEntry entry))
            {
                entry.IsDistracting = checkBox.IsChecked ?? false;
                SaveJsonData(); // Save changes back to JSON
            }
        }

        private void SearchButton_Click(object sender, RoutedEventArgs e)
        {
            if (data == null || data.Count == 0)
            {
                MessageBox.Show("No data found. Please ensure the JSON is loaded correctly.");
                return;
            }

            string searchText = SearchBox.Text.Trim().ToLower();

            if (string.IsNullOrEmpty(searchText))
            {
                MessageBox.Show("Please enter a search term.");
                return;
            }

            // Clear previous search results
            SearchResultsPanel.Children.Clear();

            // Search through all categories and URLs
            foreach (var category in data)
            {
                foreach (var entry in category.Value)
                {
                    if (entry.Url.ToLower().Contains(searchText))
                    {
                        // Create a StackPanel for each result
                        var resultPanel = new StackPanel { Orientation = Orientation.Horizontal, Margin = new Thickness(5) };

                        // Create CheckBox
                        var checkBox = new CheckBox
                        {
                            IsChecked = entry.IsDistracting,
                            Margin = new Thickness(5),
                            VerticalAlignment = VerticalAlignment.Center,
                            Tag = (category.Key, entry) // Tag to store category and entry reference
                        };
                        checkBox.Checked += CheckBox_Changed;
                        checkBox.Unchecked += CheckBox_Changed;

                        // Add URL Text
                        var urlText = new TextBlock
                        {
                            Text = entry.Url,
                            Margin = new Thickness(10, 0, 0, 0),
                            VerticalAlignment = VerticalAlignment.Center
                        };

                        // Add Category Text
                        var categoryText = new TextBlock
                        {
                            Text = $"[{category.Key}]",
                            Margin = new Thickness(10, 0, 0, 0),
                            VerticalAlignment = VerticalAlignment.Center,
                            Foreground = Brushes.Gray
                        };

                        // Add components to result panel
                        resultPanel.Children.Add(checkBox);
                        resultPanel.Children.Add(urlText);
                        resultPanel.Children.Add(categoryText);

                        // Add result panel to SearchResultsPanel
                        SearchResultsPanel.Children.Add(resultPanel);
                    }
                }
            }

            if (SearchResultsPanel.Children.Count == 0)
            {
                MessageBox.Show("No results found.");
            }
        }



        private void LoadJsonData()
        {
            try
            {
                string jsonContent = File.ReadAllText(jsonFilePath);
                data = JsonSerializer.Deserialize<Dictionary<string, List<WebsiteEntry>>>(jsonContent) ?? new();
            }
            catch (Exception ex)
            {
                MessageBox.Show($"Error loading JSON: {ex.Message}");
                data = new();
            }
        }

        private void AddButton_Click(object sender, RoutedEventArgs e)
        {
            string enteredUrl = UrlInputBox.Text.Trim();
            string selectedCategory = (CategoryComboBox.SelectedItem as ComboBoxItem)?.Content?.ToString();

            // Validate category selection
            if (string.IsNullOrEmpty(selectedCategory))
            {
                MessageBox.Show("Please select a category.", "Invalid Category", MessageBoxButton.OK, MessageBoxImage.Warning);
                return;
            }

            // Add new entry to the category
            if (!data.ContainsKey(selectedCategory))
            {
                data[selectedCategory] = new List<WebsiteEntry>();
            }

            data[selectedCategory].Add(new WebsiteEntry
            {
                Url = enteredUrl,
                IsDistracting = true
            });

            // Save changes to JSON
            SaveJsonData();
            MessageBox.Show($"URL '{enteredUrl}' added to category '{selectedCategory}'.", "Success", MessageBoxButton.OK, MessageBoxImage.Information);

            // Clear input fields
            UrlInputBox.Clear();
            CategoryComboBox.SelectedIndex = -1;
        }

        private void SaveJsonData()
        {
            try
            {
                string jsonContent = JsonSerializer.Serialize(data, new JsonSerializerOptions { WriteIndented = true });
                File.WriteAllText(jsonFilePath, jsonContent);
            }
            catch (Exception ex)
            {
                MessageBox.Show($"Error saving JSON: {ex.Message}");
            }
        }

        private void TextBox_TextChanged(object sender, TextChangedEventArgs e)
        {
            // Hier kannst du Logik hinzufügen, die bei einer Änderung im Textfeld ausgeführt werden soll.
            // Zum Beispiel:
            var textBox = sender as TextBox;
            if (textBox != null)
            {
                string inputText = textBox.Text;
                // Debug-Ausgabe oder Logik basierend auf inputText
                System.Diagnostics.Debug.WriteLine($"TextBox geändert: {inputText}");
            }
        }

        private void UrlInputBox_TextChanged(object sender, TextChangedEventArgs e)
        {
            // Überprüfen, ob die TextBox leer ist
            if (!string.IsNullOrEmpty(UrlInputBox.Text))
            {
                UrlPlaceholder.Visibility = Visibility.Collapsed; // Placeholder ausblenden
            }
            else
            {
                UrlPlaceholder.Visibility = Visibility.Visible; // Placeholder anzeigen
            }
        }


        private void NavigateToDistractionList(object sender, RoutedEventArgs e)
        {
            var clickedButton = sender as Button;

            if (clickedButton != null)
            {
                // Kategorie aus Tag lesen
                string category = clickedButton.Tag?.ToString();

                if (!string.IsNullOrEmpty(category))
                {
                    // Navigiere zur entsprechenden Seite (DistractionsList)
                    var distractionListScreen = new DistractionsList(category);
                    distractionListScreen.Show(); // Zeige neue Seite
                    this.Close(); // Schließe aktuelle Seite
                }
            }
        }



        private void Grid_MouseDown(object sender, MouseButtonEventArgs e)
        {
            var grid = sender as Grid;
            if (grid != null)
            {
                // Suche die Checkbox im Grid
                var checkbox = grid.Children.OfType<CheckBox>().FirstOrDefault();
                if (checkbox != null)
                {
                    // Toggle den Zustand der Checkbox
                    checkbox.IsChecked = !checkbox.IsChecked;
                }
            }
        }


    }
}
