﻿using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.IO;
using System.Text.Json;


namespace InnoLabProjektDektopApp
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class Settings : Window
    {
        public Settings()
        {
            InitializeComponent();
            GlobalSettings.setDefaults(this);
            MascotVisibilityChanged(null, null);
        }
        private void MascotVisibilityChanged(object sender, RoutedEventArgs e)
        {
            if (MotivationSection == null)
                return; // Beende die Methode, wenn MotivationSection noch nicht existiert.

            if (MascotVisibleNo.IsChecked == true)
            {
                MotivationSection.Visibility = Visibility.Collapsed; // Hide the section
            }
            else
            {
                MotivationSection.Visibility = Visibility.Visible; // Show the section
            }
        }



        private void TextBox_TextChanged(object sender, TextChangedEventArgs e)
        {

        }

        private void TextBox_TextChanged_1(object sender, TextChangedEventArgs e)
        {

        }

        private void ComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {

        }



private void SaveSettingsButton_Click(object sender, RoutedEventArgs e)
    {
        // Sammle die Einstellungen aus den Eingabefeldern
        string focusPeriod = ((ComboBoxItem)FocusPeriodComboBox.SelectedItem)?.Content.ToString() ?? "50 minutes";
        string breakPeriod = ((ComboBoxItem)BreakPeriodComboBox.SelectedItem)?.Content.ToString() ?? "10 minutes";
        string cycles = ((ComboBoxItem)CyclesComboBox.SelectedItem)?.Content.ToString() ?? "4";

        string distractionMode = DistractionModeFullBlocking.IsChecked == true
            ? "Full-blocking mode"
            : DistractionModeMascotFeedback.IsChecked == true
                ? "Mascot feedback only"
                : $"{SecondsComboBox.SelectedItem} seconds warning mode";

        string mascotVisible = MascotVisibleYes.IsChecked == true ? "Yes" : "No";

        bool wordsOfAffirmation = WordsOfAffirmationCheckBox.IsChecked ?? false;
        bool insultingWords = InsultingWordsCheckBox.IsChecked ?? false;

        // JSON-Datei erstellen
        var settings = new Dictionary<string, Dictionary<string, string>>
    {
        {
            "profile1",
            new Dictionary<string, string>
            {
                { "focusPeriod", focusPeriod },
                { "breakPeriod", breakPeriod },
                { "cycles", cycles },
                { "distractionMode", distractionMode },
                { "mascotVisibility", mascotVisible },
                { "wordsOfAffirmation", wordsOfAffirmation.ToString() },
                { "insultingWords", insultingWords.ToString() }
            }
        }
    };

        string filePath = System.IO.Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "settings.json");

        // JSON speichern
        File.WriteAllText(filePath, JsonSerializer.Serialize(settings, new JsonSerializerOptions { WriteIndented = true }));

        // Nach dem Speichern: JSON lesen und in der MessageBox anzeigen
        if (File.Exists(filePath))
        {
            string jsonContent = File.ReadAllText(filePath);
            var savedSettings = JsonSerializer.Deserialize<Dictionary<string, Dictionary<string, string>>>(jsonContent);

            if (savedSettings != null && savedSettings.ContainsKey("profile1"))
            {
                var profileSettings = savedSettings["profile1"];

                string message = "Saved Settings for profile1:\n";
                foreach (var setting in profileSettings)
                {
                    message += $"{setting.Key}: {setting.Value}\n";
                }

                MessageBox.Show(message, "Saved Settings", MessageBoxButton.OK, MessageBoxImage.Information);
            }
        }
    }

        private void NavigateToOverviewButton_Click(object sender, RoutedEventArgs e)
        {
            // Erstelle eine Instanz des OverviewScreen
            var overviewScreen = new Overview();

            // Zeige den OverviewScreen
            overviewScreen.Show();

            // Schließe den aktuellen Screen
            this.Close();
        }





    }
}