﻿using InnoLabProjektDektopApp.Services;
using System.IO;
using System.Text.Json;
using System.Windows;
using System.Windows.Controls;

namespace InnoLabProjektDektopApp
{
    /// <summary>
    /// Interaction logic for Overview.xaml
    /// </summary>
    public partial class Overview : Window
    {
        // Aktuelles Profil, für das Einstellungen geladen werden sollen
        private string profile = "profile1";

        // Pfad zur JSON-Datei, in der die Einstellungen gespeichert sind
        private string SettingsFilePath;

        public Overview()
        {
            InitializeComponent();
            GlobalSettings.setDefaults(this);

            // Definieren des Pfads zur JSON-Datei
            this.SettingsFilePath = System.IO.Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "settings.json");

            // Einstellungen für das aktuelle Profil laden
            LoadSettings();
        }

        // Methode, um die Einstellungen für das aktuelle Profil aus der JSON-Datei zu laden
        private void LoadSettings()
        {
            try
            {
                // JSON-Datei lesen
                if (File.Exists(SettingsFilePath))
                {
                    string jsonContent = File.ReadAllText(SettingsFilePath);
                    var settings = JsonSerializer.Deserialize<Dictionary<string, JsonElement>>(jsonContent);

                    if (settings != null && settings.ContainsKey(profile))
                    {
                        var profileSettings = settings[profile];

                        // Focus Period
                        if (profileSettings.TryGetProperty("focusPeriod", out var focusPeriodElement))
                        {
                            string focusPeriod = focusPeriodElement.GetString();
                            FocusPeriodComboBox.SelectedItem = FindComboBoxItem(FocusPeriodComboBox, focusPeriod);
                        }

                        // Break Period
                        if (profileSettings.TryGetProperty("breakPeriod", out var breakPeriodElement))
                        {
                            string breakPeriod = breakPeriodElement.GetString();
                            BreakPeriodComboBox.SelectedItem = FindComboBoxItem(BreakPeriodComboBox, breakPeriod);
                        }

                        // Cycles
                        if (profileSettings.TryGetProperty("cycles", out var cyclesElement))
                        {
                            string cycles = cyclesElement.GetString();
                            CyclesComboBox.SelectedItem = FindComboBoxItem(CyclesComboBox, cycles);
                        }

                        // Distraction Mode
                        if (profileSettings.TryGetProperty("distractionMode", out var distractionModeElement))
                        {
                            string distractionMode = distractionModeElement.GetString();
                            DistractionModeComboBox.SelectedItem = FindComboBoxItem(DistractionModeComboBox, distractionMode);
                        }

                        // Mascot Visibility
                        if (profileSettings.TryGetProperty("mascotVisibility", out var mascotVisibilityElement))
                        {
                            string mascotVisibility = mascotVisibilityElement.GetString();
                            MascotVisibilityComboBox.SelectedItem = FindComboBoxItem(MascotVisibilityComboBox, mascotVisibility);
                        }

                        // Checkbox: Words of Affirmation
                        if (profileSettings.TryGetProperty("wordsOfAffirmation", out var wordsOfAffirmationElement))
                        {
                            // Convert String to Boolean explicitly
                            WordsOfAffirmationCheckBox.IsChecked = bool.TryParse(wordsOfAffirmationElement.GetString(), out var result) && result;
                        }

                        // Checkbox: Insulting Words
                        if (profileSettings.TryGetProperty("insultingWords", out var insultingWordsElement))
                        {
                            // Convert String to Boolean explicitly
                            InsultingWordsCheckBox.IsChecked = bool.TryParse(insultingWordsElement.GetString(), out var result) && result;
                        }
                    }
                    else
                    {
                        MessageBox.Show($"No settings found for profile '{profile}'", "Info", MessageBoxButton.OK, MessageBoxImage.Information);
                    }
                }
                else
                {
                    MessageBox.Show($"Settings file not found at '{SettingsFilePath}'", "Error", MessageBoxButton.OK, MessageBoxImage.Error);
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show($"Error loading settings: {ex.Message}", "Error", MessageBoxButton.OK, MessageBoxImage.Error);
            }
        }


        // Hilfsmethode, um ein Element in der ComboBox basierend auf dem Inhalt zu finden
        private ComboBoxItem FindComboBoxItem(ComboBox comboBox, string content)
        {
            foreach (ComboBoxItem item in comboBox.Items)
            {
                if (item.Content.ToString() == content)
                {
                    return item;
                }
            }
            return null;
        }

        // Ereignis-Handler für den "Edit Profile"-Button
        private void EditProfile_Click(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("Edit Profile clicked!");
        }

        // Ereignis-Handler für den "Add Profile"-Button
        private void AddProfile_Click(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("Add Profile clicked!");
        }

        // Ereignis-Handler, um den Placeholder für das Textfeld anzuzeigen oder auszublenden
        private void FocusTopicInputBox_TextChanged(object sender, TextChangedEventArgs e)
        {
            if (!string.IsNullOrEmpty(FocusTopicInputBox.Text))
            {
                FocusTopicPlaceholder.Visibility = Visibility.Collapsed;
            }
            else
            {
                FocusTopicPlaceholder.Visibility = Visibility.Visible;
            }
        }

        // Ereignis-Handler für den "Start"-Button
        private void StartButton_Click(object sender, RoutedEventArgs e)
        {
            // Werte auslesen
            int focusPeriod = int.Parse(((ComboBoxItem)FocusPeriodComboBox.SelectedItem)?.Content.ToString().Split()[0] ?? "50");
            int breakPeriod = int.Parse(((ComboBoxItem)BreakPeriodComboBox.SelectedItem)?.Content.ToString().Split()[0] ?? "10");
            int cycles = int.Parse(((ComboBoxItem)CyclesComboBox.SelectedItem)?.Content.ToString() ?? "4");
            string distractionMode = ((ComboBoxItem)DistractionModeComboBox.SelectedItem)?.Content.ToString() ?? "Full-blocking mode";
            string mascotVisible = ((ComboBoxItem)MascotVisibilityComboBox.SelectedItem)?.Content.ToString() ?? "Yes";
            bool wordsOfAffirmation = WordsOfAffirmationCheckBox.IsChecked ?? false;
            bool insultingWords = InsultingWordsCheckBox.IsChecked ?? false;

            // Anzeige der Werte in einer MessageBox
            MessageBox.Show($"Focus Period: {focusPeriod} minutes\n" +
                            $"Break Period: {breakPeriod} minutes\n" +
                            $"Cycles: {cycles}\n" +
                            $"Distraction Mode: {distractionMode}\n" +
                            $"Mascot Visible: {mascotVisible}\n" +
                            $"Words of Affirmation: {wordsOfAffirmation}\n" +
                            $"Insulting Words: {insultingWords}",
                            "Current Settings",
                            MessageBoxButton.OK,
                            MessageBoxImage.Information);

            var sessionScreen = new Session(focusPeriod, breakPeriod, cycles, distractionMode, mascotVisible, wordsOfAffirmation, insultingWords);
            sessionScreen.Show();
            this.Close();
        }

    }
}
